/*
Solution to the BAPC Map Colouring exercise by Johan van Rooij

// @EXPECTED_RESULTS@: CORRECT

Running time: O(2^n m)
Memory usage: O(n + m)
*/

#include <iostream>
#include <vector>
using namespace std;

struct Vertex
{
	int colour; // used for greedy 2-colouring: -1 if no colour, otherwise colour 0 or 1.
	std::vector<int> neighbours;
};

std::vector<Vertex> readInput()
{
	int n, m; cin >> n >> m;
	std::vector<Vertex> input( n );
	for ( int i = 0; i < m; ++i )
	{
		int v1, v2; cin >> v1 >> v2;
		input[ v1 ].neighbours.push_back( v2 );
		input[ v2 ].neighbours.push_back( v1 );
	}
	return input;
}

bool testBit( int bitMask, int pos )
{
	return bitMask & ( 0x1 << pos );
}

bool oneColourable( const std::vector<Vertex>& graph, int bitMask = ~0x0 )
{
	// test if the subgraph induced by the bitMask vertices has no edges;
	for ( int i = 0; i < graph.size(); ++i )
	{
		if ( !testBit( bitMask, i ) )
			continue;

		const Vertex& vertex = graph[ i ];
		for ( auto it = vertex.neighbours.begin(); it != vertex.neighbours.end(); ++it )
		{
			int neighbour = *it;
			if ( testBit( bitMask, neighbour ) )
				return false;
		}
	}
	return true;
}

bool testGreedyTwoColouring( Vertex& startVertex, int colour, std::vector<Vertex>& graph, int bitMask )
{
	if ( startVertex.colour >= 0 )	// vertex already coloured
		return startVertex.colour == colour;

	startVertex.colour = colour;
	const int neighbourColour = 1 - colour;
	for ( auto it = startVertex.neighbours.begin(); it != startVertex.neighbours.end(); ++it )
	{
		int neighbour = *it;
		if ( testBit( bitMask, neighbour ) && !testGreedyTwoColouring( graph[ neighbour ], neighbourColour, graph, bitMask ) )
			return false;
	}
	return true;
}

bool twoColourable( std::vector<Vertex>& graph, int bitMask = ~0x0 )
{
	// mark graph as uncoloured.
	for ( auto it = graph.begin(); it != graph.end(); ++it )
		it->colour = -1;

	// greedily colour the subgraph induced by the bitMask vertices.
	for ( int i = 0; i < graph.size(); ++i )
	{
		if ( !testBit( bitMask, i ) )
			continue;

		Vertex& vertex = graph[ i ];
		if ( vertex.colour == -1 )
		{
			if ( !testGreedyTwoColouring( vertex, 1, graph, bitMask ) )
				return false;
		}
	}
	return true;
}

bool threeColourable( std::vector<Vertex>& graph )
{
	int partitions = ( 0x1 << (graph.size()-1) ); // -1 as we can fix the partition of the last vertex
	for ( int mask = 0x0; mask < partitions; ++mask )
	{
		if ( oneColourable( graph, mask ) && twoColourable( graph, ~mask ) )
			return true;
	}
	return false;
}

bool fourColourable( std::vector<Vertex>& graph )
{
	int partitions = ( 0x1 << (graph.size()-1) ); // -1 as we can fix the partition of the last vertex
	for ( int mask = 0x0; mask < partitions; ++mask )
	{
		if ( twoColourable( graph, mask ) && twoColourable( graph, ~mask ) )
			return true;
	}
	return false;
}

void solve()
{
	std::vector<Vertex> graph = readInput();

	if ( oneColourable( graph ) )
		cout << 1 << endl;
	else if ( twoColourable( graph ) )
		cout << 2 << endl;
	else if ( threeColourable( graph ) )
		cout << 3 << endl;
	else if ( fourColourable( graph ) )
		cout << 4 << endl;
	else
		cout << "many" << endl;
}

int main()
{
	int runs; cin >> runs;
	for ( int run = 0; run < runs; ++run )
		solve();
}
