// This versatile solution consists of very many functions that can be tied
// together in several ways. The purpose of this is to test various combinations
// of algorithms in order to see which combinations are fast enough. This is
// convenient for jury testing, but seems to make the code less suitable as
// a reference solution for teams to look at. Sorry about that!
// 
// Here is a summary of the algorithm used in this particular program:
//  *  We make a graph with one vertex for every floor that has an elevator.
//  *  The shortest path is calculated using the Bellman-Ford algorithm.
//  *  In order to interpolate the worst floor between two elevator stops,
//     we use a direct formula.
// This should be too slow.
// 
// Additional flags that may be set at compile time:
//    IGNORE_ASSERTS    (ignore all asserts in the code)
//    DEBUG_OUTPUT      (write some debug output to stderr)

#include <algorithm>
#include <iostream>
#include <limits>
#include <queue>

#ifdef IGNORE_ASSERTS
	void assert(bool) {}
#else
	#include <cassert>
#endif

using namespace std;

const int MAX_FLOORS = 1000000000;
const int MAX_ELEVATORS = 100;
const int MAX_STOPS = 1000;

//------------------------------------------------------------------------------
// General global variables and structs:
//------------------------------------------------------------------------------
int Floors, Elevators;
int Remainder[MAX_ELEVATORS + 1];
int Modulus[MAX_ELEVATORS + 1];

long long NthStop(long long numStops, long long r, long long m) {
	assert(numStops >= 1 && numStops <= MAX_STOPS + 1);
	assert(m >= 2 && m <= Floors);
	assert(r >= 0 && r < m);
	return r + (numStops - 1) * m;
}

int distanceVia(int xFloorNumber, int yFloorNumber, int yNumStairs) {
	return yNumStairs + abs(yFloorNumber - xFloorNumber);
}

struct ElevatorStop {
	int ElevatorIndex;
	int FloorNumber;
	bool operator<(const ElevatorStop& other) const {
		// By default, priority_queue is a max priority queue.
		// Therefore we must reverse the order.
		if (FloorNumber != other.FloorNumber)
			return FloorNumber > other.FloorNumber;
		return ElevatorIndex > other.ElevatorIndex;
	}
};

struct edge_t {
	int node;
	int d;
	bool operator<(const edge_t& other) const {
		// By default, priority_queue is a max priority queue.
		// Therefore we must reverse the order.
		if (d != other.d)
			return d > other.d;
		return node > other.node;
	}
};

struct answer_t {
	int NumStairs;
	int FloorNumber;
	bool operator>(const answer_t& other) const {
		if (NumStairs != other.NumStairs)
			return NumStairs > other.NumStairs;
		return FloorNumber < other.FloorNumber;
	}
	friend ostream& operator<<(ostream& os, const answer_t& ans) {
		return os << ans.NumStairs << ' ' << ans.FloorNumber;
	}
};

int make_elevator_graph();
int make_compressed_floor_graph();

void dijkstra(int, int);
void bellman_ford(int, int);
void floyd_warshall(int, int);

answer_t find_final_answer_from_elevator_graph(int, answer_t (*f)(int, int, int, int));
answer_t find_final_answer_from_compressed_floor_graph(int, answer_t (*f)(int, int, int, int));

answer_t interpolate_binary_search(int, int, int, int);
answer_t interpolate_formula(int, int, int, int);

//------------------------------------------------------------------------------
// Code specific to this solution.
// 
// This should be the only block of code that changes between my various
// solutions to the problem. This is where I patch together different parts
// of the program in order to form a working solution.
//------------------------------------------------------------------------------
const int MAX_VERTICES = MAX_STOPS * MAX_ELEVATORS + 1;

#define EXCLUDE_SQUARE_ARRAYS

answer_t specific_solution() {
	int numVertices = make_compressed_floor_graph();
	bellman_ford(numVertices, 0);
	return find_final_answer_from_compressed_floor_graph(numVertices, interpolate_formula);
}

//------------------------------------------------------------------------------
// solve(), and two more global variables that depend on MAX_VERTICES
//------------------------------------------------------------------------------
vector<edge_t> neighbours[MAX_VERTICES];
int d[MAX_VERTICES];

void solve() {
	cin >> Floors >> Elevators;
	assert(Floors >= 2 && Floors <= MAX_FLOORS);
	assert(Elevators >= 0 && Elevators <= MAX_ELEVATORS);
	// create fake elevator that stops only on the ground floor:
	Remainder[0] = 0;
	Modulus[0] = Floors;
	assert(NthStop(2, Remainder[0], Modulus[0]) >= Floors); // assert that the second stop for the fake elevator is beyond the top floor
	// read other elevators:
	for (int i = 1; i <= Elevators; i++) {
		cin >> Remainder[i] >> Modulus[i];
		assert(Modulus[i] >= 2 && Modulus[i] <= Floors);
		assert(Remainder[i] >= 0 && Remainder[i] < Modulus[i]);
		assert(NthStop(MAX_STOPS + 1, Remainder[i], Modulus[i]) >= Floors);
	}
	// actual algorithm happens in other functions:
	answer_t ans = specific_solution();
	// verify and output the answer
	assert(ans.NumStairs >= 0 && ans.NumStairs < Floors);
	assert(ans.FloorNumber >= 0 && ans.FloorNumber < Floors);
	cout << ans << endl;
}

//------------------------------------------------------------------------------
// make_elevator_graph()
// 
// Creates a graph that has one vertex for every elevator.
// Returns the number of vertices in the graph (although we know this in advance.)
//------------------------------------------------------------------------------
#ifndef EXCLUDE_SQUARE_ARRAYS
int edges[MAX_VERTICES][MAX_VERTICES];

void add_edge(int a, int b, int length) {
	assert(length >= 0);
	assert(a >= 0 && a <= Elevators);
	assert(b >= 0 && b <= Elevators);
	edges[a][b] = min(edges[a][b], length);
	edges[b][a] = min(edges[b][a], length);
	assert(edges[a][b] == edges[b][a]);
}

int make_elevator_graph() {
	priority_queue<ElevatorStop> nextStop;
	for (int i = 0; i <= Elevators; i++) {
		for (int j = 0; j <= Elevators; j++) {
			edges[i][j] = numeric_limits<int>::max();
		}
		nextStop.push((ElevatorStop) {i, Remainder[i]});
	}
	ElevatorStop prev = (ElevatorStop) {-1, -1};
	while (!nextStop.empty()) {
		ElevatorStop cur = nextStop.top();
		nextStop.pop();
		#ifdef DEBUG_OUTPUT
		cerr << "make_elevator_graph(): popped elevator (index "
		     << cur.ElevatorIndex << ", FloorNumber " << cur.FloorNumber << ")." << endl;
		#endif
		if (prev.ElevatorIndex != -1) {
			add_edge(prev.ElevatorIndex, cur.ElevatorIndex, cur.FloorNumber - prev.FloorNumber);
		}
		int NextStopForThisElevator = cur.FloorNumber + Modulus[cur.ElevatorIndex];
		if (NextStopForThisElevator < Floors) {
			nextStop.push((ElevatorStop) {cur.ElevatorIndex, NextStopForThisElevator});
		}	
		prev = cur;
	}
	for (int i = 0; i <= Elevators; i++) {
		neighbours[i].clear();
		for(int j = 0; j <= Elevators; j++) {
			if (i != j && edges[i][j] != numeric_limits<int>::max()) {
				neighbours[i].push_back((edge_t) {j, edges[i][j]});
			}
		}
	}
	return Elevators + 1;
}
#endif

//------------------------------------------------------------------------------
// make_compressed_floor_graph()
// 
// Creates a graph with one vertex for every floor that has an elevator.
// Returns the number of vertices in the graph (we don't know this in advance).
//------------------------------------------------------------------------------
int prevIndex[MAX_ELEVATORS + 1];
int FloorNumberForIndex[MAX_VERTICES];

void add_neighbours_edge(int a, int b, int length) {
	assert(length >= 0);
	neighbours[a].push_back((edge_t) {b, length});
	neighbours[b].push_back((edge_t) {a, length});
}

int make_compressed_floor_graph() {
	priority_queue<ElevatorStop> nextStop;
	for (int i = 0; i <= Elevators; i++) {
		nextStop.push((ElevatorStop) {i, Remainder[i]});
		prevIndex[i] = -1;
	}
	ElevatorStop prev = (ElevatorStop) {-1, -1};
	int numVertices = 0;
	while (!nextStop.empty()) {
		ElevatorStop cur = nextStop.top();
		nextStop.pop();
		#ifdef DEBUG_OUTPUT
		cerr << "make_compressed_floor_graph(): popped elevator (index "
		     << cur.ElevatorIndex << ", FloorNumber " << cur.FloorNumber << ")." << endl;
		#endif
		if (prev.FloorNumber != cur.FloorNumber) {
			// create new vertex
			assert(cur.FloorNumber > prev.FloorNumber);
			numVertices++;
			assert(numVertices <= MAX_VERTICES);
			FloorNumberForIndex[numVertices - 1] = cur.FloorNumber;
			neighbours[numVertices - 1].clear();
			if (numVertices >= 2) {
				add_neighbours_edge(numVertices - 2, numVertices - 1, cur.FloorNumber - prev.FloorNumber);
			}
		}
		if (prev.ElevatorIndex != -1) {
			if (prevIndex[cur.ElevatorIndex] != -1) {
				add_neighbours_edge(numVertices - 1, prevIndex[cur.ElevatorIndex], 0);
			}
			prevIndex[cur.ElevatorIndex] = numVertices - 1;
		}
		int NextStopForThisElevator = cur.FloorNumber + Modulus[cur.ElevatorIndex];
		if (NextStopForThisElevator < Floors) {
			nextStop.push((ElevatorStop) {cur.ElevatorIndex, NextStopForThisElevator});
		}	
		prev = cur;
	}
	return numVertices;
}

//------------------------------------------------------------------------------
// dijkstra(int numVertices, int start)
// 
// Performs Dijkstra's algorithm on whatever graph is stored in the variable
// vector<int> neighours[MAX_VERTICES].
// 
// Results are stored in the array int d[MAX_VERTICES].
//------------------------------------------------------------------------------
void dijkstra(int numVertices, int start) {
	// step 0: constraint checking
	assert(numVertices >= 1 && numVertices <= MAX_VERTICES);
	assert(start >= 0 && start < numVertices);
	// step 1: initialisation
	fill_n(d, numVertices, numeric_limits<int>::max());
	priority_queue<edge_t> q;
	d[start] = 0;
	q.push((edge_t) {start, d[start]});
	// step 2: actual algorithm
	while (!q.empty()) {
		edge_t cur = q.top();
		q.pop();
		#ifdef DEBUG_OUTPUT
			cerr << "dijkstra(int, int): popped vertex (node = " << cur.node << ", distance = " << cur.d << ")." << endl;
		#endif
		if (cur.d > d[cur.node]) continue;
		assert(cur.d == d[cur.node]);
		assert(cur.d != numeric_limits<int>::max());
		for (vector<edge_t>::iterator it = neighbours[cur.node].begin(); it != neighbours[cur.node].end(); it++) {
			int newD = cur.d + it->d;
			if (newD < d[it->node]) {
				d[it->node] = newD;
				q.push((edge_t) {it->node, d[it->node]});
			}
		}
	}
}

//------------------------------------------------------------------------------
// bellman_ford(int numVertices, int start)
// 
// Performs the Bellman-Ford algorithm on whatever graph is stored in the
// variable vector<int> neighours[MAX_VERTICES].
// 
// Results are stored in the array int d[MAX_VERTICES].
//------------------------------------------------------------------------------
void bellman_ford(int numVertices, int start) {
	// step 0: constraint checking
	assert(numVertices >= 1 && numVertices <= MAX_VERTICES);
	assert(start >= 0 && start < numVertices);
	// step 1: initialisation
	for (int i = 0; i < numVertices; i++) {
		d[i] = numeric_limits<int>::max() / 2;
	}
	d[start] = 0;
	// step 2: actual algorithm
	for (int i = 1; i < numVertices; i++) {
		for (int j = 0; j < numVertices; j++) {
			for (vector<edge_t>::iterator it = neighbours[j].begin(); it != neighbours[j].end(); it++) {
				d[it->node] = min(d[it->node], d[j] + it->d);
			}
		}
	}
}

//------------------------------------------------------------------------------
// floyd_warshall(int numVertices, int start)
// 
// Performs the Floyd-Warshall algorithm on whatever graph is stored in the
// variable vector<int> neighours[MAX_VERTICES].
// 
// The lengths of the shortest paths from the given start vertex are then stored
// in the array int d[MAX_VERTICES], so that this algorithm is compatible with
// the other two shortest path algorithms.
//------------------------------------------------------------------------------
#ifndef EXCLUDE_SQUARE_ARRAYS
int all_to_all[MAX_VERTICES][MAX_VERTICES];

void floyd_warshall(int numVertices, int start) {
	// step 0: constraint checking
	assert(numVertices >= 1 && numVertices <= MAX_VERTICES);
	assert(start >= 0 && start < numVertices);
	// step 1: initialisation
	for (int i = 0; i < numVertices; i++) {
		for (int j = 0; j < numVertices; j++) {
			all_to_all[i][j] = (i == j ? 0 : numeric_limits<int>::max() / 2);
		}
	}
	// step 2: copy the graph from adjacency list to adjacency matrix
	for (int i = 0; i < numVertices; i++) {
		for (vector<edge_t>::iterator it = neighbours[i].begin(); it != neighbours[i].end(); it++) {
			all_to_all[i][it->node] = min(all_to_all[i][it->node], it->d);
		}
	}
	// step 3: perform actual algorithm
	for (int k = 0; k < numVertices; k++) {
		for (int i = 0; i < numVertices; i++) {
			for (int j = 0; j < numVertices; j++) {
				all_to_all[i][j] = min(all_to_all[i][j], all_to_all[i][k] + all_to_all[k][j]);
			}
		}
	}
	// step 4: write single-source shortest path lengths
	for (int i = 0; i < numVertices; i++) {
		d[i] = all_to_all[start][i];
	}
}
#endif

//------------------------------------------------------------------------------
// find_final_answer_from_elevator_graph(int numVertices, answer_t (*f)(int, int, int, int))
// 
// Performs a sweep line from the ground floor all the way to the top floor in
// order to find the final answer.
// 
// Before this function is called, the array int d[MAX_VERTICES] should contain
// the minimum number of stairs a guest needs to take before he can find himself
// inside any given elevator.
//------------------------------------------------------------------------------
answer_t find_final_answer_from_elevator_graph(int numVertices, answer_t (*find_worst_intermediate_floor)(int, int, int, int)) {
	priority_queue<ElevatorStop> nextStop;
	for (int i = 0; i < numVertices; i++) {
		nextStop.push((ElevatorStop) {i, Remainder[i]});
	}
	ElevatorStop prev = (ElevatorStop) {-1, -1};
	answer_t ans = (answer_t) {0, 0};
	while (!nextStop.empty()) {
		ElevatorStop cur = nextStop.top();
		nextStop.pop();
		#ifdef DEBUG_OUTPUT
			cerr << "find_final_answer_from_elevator_graph(answer_t (*f)(int, int, int, int)): "
			        "popped elevator (index " << cur.ElevatorIndex << ", FloorNumber " << cur.FloorNumber << ")." << endl;
		#endif
		if (prev.ElevatorIndex != -1) {
			answer_t newAns = find_worst_intermediate_floor(prev.FloorNumber, d[prev.ElevatorIndex],
			                                                cur.FloorNumber,  d[cur.ElevatorIndex]);
			#ifdef DEBUG_OUTPUT
				cerr << "find_final_answer_from_elevator_graph(answer_t (*f)(int, int, int, int)): newAns = " << newAns << endl;
			#endif
			if (newAns > ans) ans = newAns;
		}
		int NextStopForThisElevator = cur.FloorNumber + Modulus[cur.ElevatorIndex];
		if (NextStopForThisElevator < Floors) {
			nextStop.push((ElevatorStop) {cur.ElevatorIndex, NextStopForThisElevator});
		}	
		prev = cur;
	}
	// don't forget to check beyond the final elevator stop:
	answer_t topFloorAns;
	if (prev.ElevatorIndex != -1) {
		topFloorAns = (answer_t) {distanceVia(Floors - 1, prev.FloorNumber, d[prev.ElevatorIndex]), Floors - 1};
	}
	else {
		// there are no elevators
		topFloorAns = (answer_t) {Floors - 1, Floors - 1};
	}
	if (topFloorAns > ans) ans = topFloorAns;
	return ans;
}

//------------------------------------------------------------------------------
// find_final_answer_from_compressed_floor_graph(int numVertices, answer_t (*f)(int, int, int, int))
// 
// Performs a sweep line from the ground floor all the way to the top floor in
// order to find the final answer.
//------------------------------------------------------------------------------
answer_t find_final_answer_from_compressed_floor_graph(int numVertices, answer_t (*find_worst_intermediate_floor)(int, int, int, int)) {
	answer_t ans = (answer_t) {0, 0};
	for (int i = 1; i < numVertices; i++) {
		answer_t newAns = find_worst_intermediate_floor(FloorNumberForIndex[i - 1], d[i - 1],
		                                                FloorNumberForIndex[i]    , d[i]      );
		if (newAns > ans) ans = newAns;
	}
	// don't forget to check beyond the final elevator stop:
	answer_t topFloorAns;
	if (numVertices > 0) {
		topFloorAns = (answer_t) {distanceVia(Floors - 1, FloorNumberForIndex[numVertices - 1], d[numVertices - 1]), Floors - 1};
	}
	else {
		topFloorAns = (answer_t) {Floors - 1, Floors - 1};
	}
	if (topFloorAns > ans) ans = topFloorAns;
	return ans;
}

//------------------------------------------------------------------------------
// interpolate_binary_search(int, int, int, int)
// 
// Given two floors for which we know the minimum distance from the hotel
// entrance, find the worst intermediate floor. Mind you, if two floors are
// equally bad, we must return the lower of the two!
// 
// This function finds the minimum by binary search.
//------------------------------------------------------------------------------
answer_t interpolate_binary_search(int aFloorNumber, int aNumStairs, int bFloorNumber, int bNumStairs) {
	// step 0: constraint checking
	assert(aFloorNumber <= bFloorNumber);
	assert(aNumStairs >= 0 && aNumStairs != numeric_limits<int>::max());
	assert(bNumStairs >= 0 && bNumStairs != numeric_limits<int>::max());
	// step 1: handle edge cases
	int diff = bFloorNumber - aFloorNumber;
	if (aNumStairs + diff <= bNumStairs) {
		assert(aNumStairs + diff == bNumStairs);
		return (answer_t) {bNumStairs, bFloorNumber};
	}
	if (bNumStairs + diff <= aNumStairs) {
		assert(bNumStairs + diff == aNumStairs);
		return (answer_t) {aNumStairs, aFloorNumber};
	}
	// step 2: perform binary search
	int lo = aFloorNumber;
	int hi = bFloorNumber;
	while (hi - lo > 1) {
		int mid = (lo + hi) / 2;
		(distanceVia(mid, bFloorNumber, bNumStairs) < distanceVia(mid, aFloorNumber, aNumStairs) ? hi : lo) = mid;
	}
	// step 3: verify found answer and return it
	assert(lo >= aFloorNumber && lo < bFloorNumber);
	answer_t ans = (answer_t) {distanceVia(lo, aFloorNumber, aNumStairs), lo};
	assert(ans.NumStairs <= distanceVia(lo, bFloorNumber, bNumStairs));
	assert(distanceVia(lo + 1, aFloorNumber, aNumStairs) > distanceVia(lo + 1, bFloorNumber, bNumStairs));
	return ans;
}

//------------------------------------------------------------------------------
// interpolate_formula(int, int, int, int)
// 
// Given two floors for which we know the minimum distance from the hotel
// entrance, find the worst intermediate floor. Mind you, if two floors are
// equally bad, we must return the lower of the two!
// 
// This function finds the minimum using a direct formula.
//------------------------------------------------------------------------------
answer_t interpolate_formula(int aFloorNumber, int aNumStairs, int bFloorNumber, int bNumStairs) {
	// step 0: constraint checking
	assert(aFloorNumber <= bFloorNumber);
	assert(aNumStairs >= 0 && aNumStairs != numeric_limits<int>::max());
	assert(bNumStairs >= 0 && bNumStairs != numeric_limits<int>::max());
	// step 1: direct formula
	int aFloorNumberCorrected = aFloorNumber - aNumStairs;
	int bFloorNumberCorrected = bFloorNumber + bNumStairs;
	int half = (bFloorNumberCorrected + aFloorNumberCorrected) / 2;
	// step 2: verify found answer and return it
	assert(half >= aFloorNumber && half <= bFloorNumber);
	answer_t ans = (answer_t) {distanceVia(half, aFloorNumber, aNumStairs), half};
	assert(ans.NumStairs <= distanceVia(half, bFloorNumber, bNumStairs));
	if (half < bFloorNumber)
		assert(distanceVia(half + 1, aFloorNumber, aNumStairs) > distanceVia(half + 1, bFloorNumber, bNumStairs));
	else
		assert(ans.NumStairs == bNumStairs);
	return ans;
}

//------------------------------------------------------------------------------
// int main()
//------------------------------------------------------------------------------
int main() {
	int T;
	cin >> T;
	for (int i = 0; i < T; i++)
		solve();
	return 0;
}
